=======
Credits
=======

Development Lead
----------------

* Audrey Roy <audreyr@gmail.com>

Contributors
------------

* Daniel Greenfeld (`@pydanny`_)
* Steven Loria (`@sloria`_)
* Goran Peretin (`@gperetin`_)
* Hamish Downer (`@foobacca`_)
* Thomas Orozco (`@krallin`_)
* Jindrich Smitka (`@s-m-i-t-a`_)
* Benjamin Schwarze (`@benjixx`_)
* Raphi (`@raphigaziano`_)
* Thomas Chiroux (`@ThomasChiroux`_)
* Sergi Almacellas Abellana (`@pokoli`_)
* Alex Gaynor (`@alex`_)
* Rolo (`@rolo`_)
* Pablo (`@oubiga`_)
* Michael Joseph (`@michaeljoseph`_)
* Bruno Rocha (`@rochacbruno`_)
* Alexander Artemenko (`@svetlyak40wt`_)
* Mahmoud Abdelkader (`@mahmoudimus`_)
* Leonardo Borges Avelino (`@lborgav`_)
* Chris Trotman (`@solarnz`_)
* Rolf (`@relekang`_)
* Noah Kantrowitz (`@coderanger`_)
* Vincent Bernat (`@vincentbernat`_)
* Germán Moya (`@pbacterio`_)
* Ned Batchelder (`@nedbat`_)
* Dave Dash (`@davedash`_)
* Johan Charpentier (`@cyberj`_)

.. _`@vincentbernat`: https://github.com/vincentbernat
.. _`@audreyr`: https://github.com/audreyr
.. _`@pydanny`: https://github.com/pydanny
.. _`@sloria`: https://github.com/sloria
.. _`@gperetin`: https://github.com/gperetin
.. _`@foobacca`: https://github.com/foobacca
.. _`@krallin`: https://github.com/krallin
.. _`@s-m-i-t-a`: https://github.com/s-m-i-t-a
.. _`@benjixx`: https://github.com/benjixx
.. _`@raphigaziano`: https://github.com/raphigaziano
.. _`@ThomasChiroux`: https://github.com/ThomasChiroux
.. _`@pokoli`: https://github.com/pokoli
.. _`@alex`: https://github.com/alex
.. _`@rolo`: https://github.com/rolo
.. _`@oubiga`: https://github.com/oubiga
.. _`@michaeljoseph`: https://github.com/michaeljoseph
.. _`@rochacbruno`: https://github.com/rochacbruno
.. _`@svetlyak40wt`: https://github.com/svetlyak40wt
.. _`@mahmoudimus`: https://github.com/mahmoudimus
.. _`@lborgav`: https://github.com/lborgav
.. _`@solarnz`: https://github.com/solarnz
.. _`@relekang`: https://github.com/relekang
.. _`@coderanger`: https://github.com/coderanger
.. _`@pbacterio`: https://github.com/pbacterio
.. _`@nedbat`: https://github.com/nedbat
.. _`@davedash`: https://github.com/davedash
.. _`@cyberj`: https://github.com/cyberj
